/************* 系统设置 *********************/
var ActionXML = "Action.xml";
var Dep_Server = "DepSrv.aspx";
var User_Server = "UserSrv.aspx";
var Lmt_Server = "LimitSrv.aspx";

/*****************  document.ready start ********************/
$(document).ready(function () {

    /***************** 部门管理开始 ******************/
    $("#dep").bind("click", function () {
        //构造 部门管理DIV
        Left_Menu_Click("dep", "部门管理", true);
        getAlldep();
        //部门管理 新增按钮点击事件
        $("#Insert_dep").bind("click", function () {
            //构造 新增部门管理DIV
            ActionDiv("Insert", "dep", "新增部门管理");
            //读取XML 获取新增表单
            $.get(ActionXML, function (data) {
                $("#Insert_Con_dep").html($(data).find("Action[name='Insertdep']").html());
                $("#depSave").unbind();
                $("#depSave").bind("click", function () {
                    depSaveClick();
                });
            });
            //重新定义部门管理 新增按钮点击事件
            $("#Insert_dep").unbind();
            $("#Insert_dep").bind("click", function () {
                Show_Action_Box("Insertdep");
            });
        });
        //部门管理 修改按钮点击事件
        $("#Update_dep").bind("click", function () {
            var id = CheckBoxVal("depSTD");
            if (id == "" || id.indexOf(",") >= 0) {
                alert("请选择一个需要修改的部门信息");
                return;
            }
            //构造 修改部门管理DIV
            ActionDiv("Update", "dep", "修改部门管理");
            //读取XML 获取修改表单
            $.get(ActionXML, function (data) {
                $("#Update_Con_dep").html($(data).find("Action[name='Updatedep']").html());
                GetDepVal(id);
                $("#depUpdate").unbind();
                $("#depUpdate").bind("click", function () {
                    depUpdateClick();
                });
            });
            //重新定义部门管理 修改按钮点击事件
            $("#Update_dep").unbind();
            $("#Update_dep").bind("click", function () {
                var id2 = CheckBoxVal("depSTD");
                if (id2 == "" || id2.indexOf(",") >= 0) {
                    alert("请选择一个需要修改的部门信息");
                    return;
                }
                GetDepVal(id2);
                Show_Action_Box("Updatedep");
            });
        });
        //绑定搜索按钮点击事件
        $("#searchB_dep").unbind();
        $("#searchB_dep").bind("click", function () {
            getAlldep();
        });
        //绑定删除按钮点击事件
        $("#Del_dep").unbind();
        $("#Del_dep").bind("click", function () {
            depDelClick();
        });
    });
    /***************** 部门管理结束 ******************/

    /***************** 用户管理开始 ******************/
    $("#user").bind("click", function () {
        //构造 用户管理DIV
        Left_Menu_Click("user", "用户管理", true);
        Vmenu("user", "选择部门:<select id=\"menuDepSelect\"></select>");
        SelectDep("menuDepSelect", "");
        $("#menuDepSelect").change(function () { getAlluser(); });
        //加载等待
        Cloading("Con_user");
        setTimeout('getAlluser()', 3000);
        //用户管理 新增按钮点击事件
        $("#Insert_user").bind("click", function () {
            //构造 新增用户管理DIV
            ActionDiv("Insert", "user", "新增用户管理");
            //读取XML 获取新增表单
            $.get(ActionXML, function (data) {
                $("#Insert_Con_user").html($(data).find("Action[name='Insertuser']").html());
                SelectDep("userDep", "");
                $("#userSave").unbind();
                $("#userSave").bind("click", function () {
                    userSaveClick();
                });
            });
            //重新定义用户管理 新增按钮点击事件
            $("#Insert_user").unbind();
            $("#Insert_user").bind("click", function () {
                Show_Action_Box("Insertuser");
            });
        });
        //用户管理 修改按钮点击事件
        $("#Update_user").bind("click", function () {
            var id = CheckBoxVal("userSTD");
            if (id == "" || id.indexOf(",") >= 0) {
                alert("请选择一个需要修改的用户信息");
                return;
            }
            //构造 修改用户管理DIV
            ActionDiv("Update", "user", "修改用户管理");
            //读取XML 获取修改表单
            $.get(ActionXML, function (data) {
                $("#Update_Con_user").html($(data).find("Action[name='Updateuser']").html());
                GetuserVal(id);
                $("#userUpdate").unbind();
                $("#userUpdate").bind("click", function () {
                    userUpdateClick();
                });
            });
            //重新定义用户管理 修改按钮点击事件
            $("#Update_user").unbind();
            $("#Update_user").bind("click", function () {
                var id2 = CheckBoxVal("userSTD");
                if (id2 == "" || id2.indexOf(",") >= 0) {
                    alert("请选择一个需要修改的用户信息");
                    return;
                }
                GetuserVal(id);
                Show_Action_Box("Updateuser");
            });
        });
        //绑定搜索按钮点击事件
        $("#searchB_user").unbind();
        $("#searchB_user").bind("click", function () {
            getAlluser();
        });
        //绑定删除按钮点击事件
        $("#Del_user").unbind();
        $("#Del_user").bind("click", function () {
            userDelClick();
        });
    });

    /***************** 用户管理结束 ******************/

    /***************** 权限管理开始 ******************/
    $("#limit").bind("click", function () {
        //构造 权限管理DIV
        Left_Menu_Click("limit", "权限管理", false);
        Vmenu("limit", "<input id=\"searchT_limit\" type=\"text\"/><input value=\"搜索\" id=\"searchB_limit\" type=\"button\">");
        Vmenu("limit", "选择部门:<select id=\"menuLmtSelect\"></select>");
        Vmenu("limit", "<input value=\"修改用户权限\" id=\"update_limit\" type=\"button\">");
        SelectDep("menuLmtSelect", "");
        $("#menuLmtSelect").change(function () { getLmtuser(); });
        //加载等待
        Cloading("Con_limit");
        setTimeout('getLmtuser()', 3000);
        //绑定搜索按钮点击事件
        $("#searchB_limit").unbind();
        $("#searchB_limit").bind("click", function () {
            getLmtuser();
        });
        //权限管理 修改按钮点击事件
        $("#update_limit").bind("click", function () {
            var id = CheckBoxVal("lmtUserSTD");
            if (id == "" || id.indexOf(",") >= 0) {
                alert("请选择一个需要修改的用户信息");
                return;
            }
            var input = "#lmtUserSTD input[value='" + id + "']";
            var td = $(input).parent();
            //构造 修改用户权限管理DIV
            ActionDiv("Update", "lmt", "修改用户权限--" + $(td).next().text());
            getLmtList(id);
            //重新定义权限管理 修改按钮点击事件
            $("#update_limit").unbind();
            $("#update_limit").bind("click", function () {
                var id2 = CheckBoxVal("lmtUserSTD");
                if (id2 == "" || id2.indexOf(",") >= 0) {
                    alert("请选择一个需要修改的用户信息");
                    return;
                }
                var input2 = "#lmtUserSTD input[value='" + id2 + "']";
                var td2 = $(input2).parent();
                $("#Updatelmt").find(".Box_info").html("修改用户权限--" + $(td2).next().text() + "<div class=\"Box_Close\">关闭</div>");
                Close_Main_Box();
                getLmtList(id2);
                Show_Action_Box("Updatelmt");
            });
        });
    });

    /***************** 权限管理结束  ******************/

    /***************** 系统日志开始 ******************/
    $("#sysLog").bind("click", function () {
        //构造 系统日志DIV
        Left_Menu_Click("sysLog", "系统日志", false);
        Vmenu("sysLog", "时间:<input id=\"searchT_log\" type=\"date\"/> &nbsp;用户姓名或操作<input id=\"searchN_log\" type=\"text\"/><input value=\"搜索\" id=\"searchB_log\" type=\"button\">");
        getSysLog();
        //绑定搜索按钮点击事件
        $("#searchB_log").unbind();
        $("#searchB_log").bind("click", function () {
            getSysLog();
        });
    });
    /***************** 系统日志结束 ******************/
});
/*****************  document.ready  end ********************/

/*****************  Dep start  ********************/
//获取部门列表
function getAlldep() {
    //获取数据
    var s = $("#searchT_dep").val();
    //加载等待
    Cloading("Con_dep");
    //执行ajax
    $.get(Dep_Server, { type: "GetAllDep", sT: s }, function (data) {
        //等待结束
        Cstop();
        if (data != "") {
            $("#Con_dep").html(data);
        }
    });
}

//新增部门管理保存点击事件
function depSaveClick() {
    //获取数据
    var n = $("#depName").val();
    var r = $("#depRemark").val();
    
    //加载等待
    loading("depSave");

    //执行ajax
    $.get(Dep_Server, { type: "SysDepSave", name: n, remark: r, id: "" }, function (data) {
        //等待结束
        stopW("depSave");

        if (data == "true") {
            CloseBox("Insertdep");             //关闭新增窗口
            clearDataForm("depTable");         //清空新增窗口的表单数据
            getAlldep();                     //重新获取数据
        }
        else {
            alert("新增失败...失败原因:" + data);
        }
    });
}
//获取修改部门表单值
function GetDepVal(id) {
    var input = "#depSTD input[value='" + id + "']";
    var td = $(input).parent();
    $("#depNameU").val($(td).next().text());
    $("#depRemarkU").val($(td).next().next().text());
    $("#Updatedep").attr("did", id);
}

//修改部门管理保存点击事件
function depUpdateClick() {
    //获取数据
    var n = $("#depNameU").val();
    var r = $("#depRemarkU").val();
    var i = $("#Updatedep").attr("did");

    //加载等待
    loading("depUpdate");

    //执行ajax
    $.get(Dep_Server, { type: "SysDepUpdate", name: n, remark: r, id: i }, function (data) {
        //等待结束
        stopW("depUpdate");

        if (data == "true") {
            CloseBox("Updatedep");             //关闭新增窗口
            getAlldep();                      //重新获取数据
        }
        else {
            alert("修改失败...失败原因:" + data);
        }
    });
}

//删除部门信息
function depDelClick() {
    var ids = CheckBoxVal("depSTD");
    if (ids == "") {
        alert("请选择需要删除的部门信息");
        return;
    }
    //加载等待
    Cloading("Con_dep");
    //执行ajax
    $.get(Dep_Server, { type: "SysDepDel", id: ids }, function (data) {
        //等待结束
        Cstop();
        if (data == "true") {
            getAlldep();                 //重新获取数据
        }
        else {
            alert("删除失败...失败原因:" + data);
        }
    });
}

/*****************  Dep end  ********************/

/*****************  user start  ********************/

//新增用户管理保存点击事件
function userSaveClick() {
    //获取数据
    var n = $("#userName").val();
    var m = $("#userMobile").val();
    var d = $("#userDep").val();
    var a = $("#userAccount").val();

    //判断数量是否为数字
    if (!IsNum(m)) {
        alert("数量请输入数字!");
        return;
    }
    //加载等待
    loading("userSave");

    //执行ajax
    $.get(User_Server, { type: "SysUserSave", name: n, mobile: m, depid: d, useracc: a,id: "" }, function (data) {
        //等待结束
        stopW("userSave");

        if (data == "true") {
            CloseBox("Insertuser");             //关闭新增窗口
            clearDataForm("userTable");         //清空新增窗口的表单数据
            getAlluser();                     //重新获取数据
        }
        else {
            alert("新增失败...失败原因:" + data);
        }
    });
}
//修改用户管理保存点击事件
function userUpdateClick() {
    //获取数据
    var n = $("#userNameU").val();
    var m = $("#userMobileU").val();
    var d = $("#userDepU").val();
    var a = $("#userAccountU").val();
    var i = $("#Updateuser").attr("Uid");

    //判断数量是否为数字
    if (!IsNum(m)) {
        alert("手机号码请输入数字!");
        return;
    }

    //加载等待
    loading("userUpdate");

    //执行ajax
    $.get(User_Server, { type: "SysUserUpdate", name: n, mobile: m, depid: d, useracc: a, id: i }, function (data) {
        //等待结束
        stopW("userUpdate");

        if (data == "true") {
            CloseBox("Updateuser");             //关闭新增窗口
            getAlluser();                      //重新获取数据
        }
        else {
            alert("修改失败...失败原因:" + data);
        }
    });
}

//删除用户信息
function userDelClick() {
    var ids = CheckBoxVal("userSTD");
    if (ids == "") {
        alert("请选择需要删除的用户信息");
        return;
    }
    //加载等待
    Cloading("Con_user");
    //执行ajax
    $.get(User_Server, { type: "SysUserDel", id: ids }, function (data) {
        //等待结束
        Cstop();
        if (data == "true") {
            getAlluser();                //重新获取数据
        }
        else {
            alert("删除失败...失败原因:" + data);
        }
    });
}

//获取用户列表
function getAlluser() {
    //获取数据
    var s = $("#searchT_user").val();
    var d = $("#menuDepSelect").val();

    //等待结束
    Cstop();
    //加载等待
    Cloading("Con_user");
    
    //执行ajax
    $.get(User_Server, { type: "GetAllUser", sT: s, depid: d,tName:"userSTD" }, function (data) {
        //等待结束
        Cstop();
        if (data != "") {
            $("#Con_user").html(data);
        }
    });
}

//获取修改用户表单值
function GetuserVal(id) {
    var input = "#userSTD input[value='" + id + "']";
    var td = $(input).parent();
    $("#userNameU").val($(td).next().text());
    $("#userMobileU").val($(td).next().next().text());
    $("#userAccountU").val($(td).next().next().next().text());
    $("#Updateuser").attr("Uid", id);
    SelectDep("userDepU", $("#menuDepSelect").val());        //构建部门选择框
}

/*****************  user end  ********************/

/*****************  limit start  ********************/
//获取用户列表
function getLmtuser() {
    //获取数据
    var s = $("#searchT_limit").val();
    var d = $("#menuLmtSelect").val();

    //等待结束
    Cstop();
    //加载等待
    Cloading("Con_limit");

    //执行ajax
    $.get(User_Server, { type: "GetLmtUser", sT: s, depid: d,tName:"lmtUserSTD" }, function (data) {
        //等待结束
        Cstop();
        if (data != "") {
            $("#Con_limit").html(data);
        }
    });
}

//获取权限列表
function getLmtList(i) {

    //加载等待
    Cloading("Update_Con_lmt");

    //执行ajax
    $.get(Lmt_Server, { type: "GetOpList", id: i }, function (data) {
        //等待结束
        Cstop();
        if (data != "") {
            $("#Update_Con_lmt").html(data);
            //权限列表伸缩
            $(".lmtListTitle").each(function () {
                $(this).click(function () {
                    $(this).next().slideToggle();
                });
            });
            //绑定保存按钮点击事件
            $("#lmtSave").unbind();
            $("#lmtSave").bind("click", function () {
                lmtSaveClick(i);
            });
        }
    });
}

//保存用户权限
function lmtSaveClick(i) {
    //获取数据
    var o = NoCheckBoxVal("lmtList");

    //加载等待
    loading("lmtSave");

    //执行ajax
    $.get(Lmt_Server, { type: "UpdateLmt", id: i ,ops:o}, function (data) {
        //等待结束
        stopW("lmtSave");

        if (data == "true") {
            CloseBox("Updatelmt");             //关闭新增窗口
        }
        else {
            alert("修改失败...失败原因:" + data);
        }
    });
}
/*****************  limit end  ********************/

/*****************  log start  ********************/
//获取日志列表
function getSysLog() {
    //获取数据
    var s = $("#searchT_log").val();
    var n = $("#searchN_log").val();
    
    //加载等待
    Cloading("Con_sysLog");

    //执行ajax
    $.get(Lmt_Server, { type: "GetSysLog", sT: s,sN:n}, function (data) {
        //等待结束
        Cstop();
        if (data != "") {
            $("#Con_sysLog").html(data);
        }
    });
}
/*****************  log end  ********************/